# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['CustomerManagedKeyArgs', 'CustomerManagedKey']

@pulumi.input_type
class CustomerManagedKeyArgs:
    def __init__(__self__, *,
                 customer_managed_key_id: pulumi.Input[_builtins.str],
                 data_factory_id: pulumi.Input[_builtins.str],
                 user_assigned_identity_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a CustomerManagedKey resource.

        :param pulumi.Input[_builtins.str] customer_managed_key_id: The ID the of the Customer Managed Key to associate with the Data Factory.
        :param pulumi.Input[_builtins.str] data_factory_id: The ID of the Data Factory Resource the Customer Managed Key will be associated with. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] user_assigned_identity_id: The User Assigned Identity ID that will be used to access Key Vaults that contain the encryption keys.
        """
        pulumi.set(__self__, "customer_managed_key_id", customer_managed_key_id)
        pulumi.set(__self__, "data_factory_id", data_factory_id)
        if user_assigned_identity_id is not None:
            pulumi.set(__self__, "user_assigned_identity_id", user_assigned_identity_id)

    @_builtins.property
    @pulumi.getter(name="customerManagedKeyId")
    def customer_managed_key_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID the of the Customer Managed Key to associate with the Data Factory.
        """
        return pulumi.get(self, "customer_managed_key_id")

    @customer_managed_key_id.setter
    def customer_managed_key_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "customer_managed_key_id", value)

    @_builtins.property
    @pulumi.getter(name="dataFactoryId")
    def data_factory_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Data Factory Resource the Customer Managed Key will be associated with. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "data_factory_id")

    @data_factory_id.setter
    def data_factory_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "data_factory_id", value)

    @_builtins.property
    @pulumi.getter(name="userAssignedIdentityId")
    def user_assigned_identity_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The User Assigned Identity ID that will be used to access Key Vaults that contain the encryption keys.
        """
        return pulumi.get(self, "user_assigned_identity_id")

    @user_assigned_identity_id.setter
    def user_assigned_identity_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_assigned_identity_id", value)


@pulumi.input_type
class _CustomerManagedKeyState:
    def __init__(__self__, *,
                 customer_managed_key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 data_factory_id: Optional[pulumi.Input[_builtins.str]] = None,
                 user_assigned_identity_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering CustomerManagedKey resources.

        :param pulumi.Input[_builtins.str] customer_managed_key_id: The ID the of the Customer Managed Key to associate with the Data Factory.
        :param pulumi.Input[_builtins.str] data_factory_id: The ID of the Data Factory Resource the Customer Managed Key will be associated with. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] user_assigned_identity_id: The User Assigned Identity ID that will be used to access Key Vaults that contain the encryption keys.
        """
        if customer_managed_key_id is not None:
            pulumi.set(__self__, "customer_managed_key_id", customer_managed_key_id)
        if data_factory_id is not None:
            pulumi.set(__self__, "data_factory_id", data_factory_id)
        if user_assigned_identity_id is not None:
            pulumi.set(__self__, "user_assigned_identity_id", user_assigned_identity_id)

    @_builtins.property
    @pulumi.getter(name="customerManagedKeyId")
    def customer_managed_key_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID the of the Customer Managed Key to associate with the Data Factory.
        """
        return pulumi.get(self, "customer_managed_key_id")

    @customer_managed_key_id.setter
    def customer_managed_key_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "customer_managed_key_id", value)

    @_builtins.property
    @pulumi.getter(name="dataFactoryId")
    def data_factory_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Data Factory Resource the Customer Managed Key will be associated with. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "data_factory_id")

    @data_factory_id.setter
    def data_factory_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "data_factory_id", value)

    @_builtins.property
    @pulumi.getter(name="userAssignedIdentityId")
    def user_assigned_identity_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The User Assigned Identity ID that will be used to access Key Vaults that contain the encryption keys.
        """
        return pulumi.get(self, "user_assigned_identity_id")

    @user_assigned_identity_id.setter
    def user_assigned_identity_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_assigned_identity_id", value)


@pulumi.type_token("azure:datafactory/customerManagedKey:CustomerManagedKey")
class CustomerManagedKey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 customer_managed_key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 data_factory_id: Optional[pulumi.Input[_builtins.str]] = None,
                 user_assigned_identity_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a Customer Managed Key for a Data Factory.

        > **Note:** The Customer Managed Key cannot be removed from the Data Factory once added. To remove the Customer Managed Key delete and recreate the parent Data Factory.

        ## Example Usage

        ### With System Assigned Identity

        ```python
        import pulumi
        import pulumi_azure as azure

        current = azure.core.get_client_config()
        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_key_vault = azure.keyvault.KeyVault("example",
            name="example-key-vault",
            location=example.location,
            resource_group_name=example.name,
            tenant_id=current.tenant_id,
            sku_name="standard",
            purge_protection_enabled=True)
        example_key = azure.keyvault.Key("example",
            name="examplekey",
            key_vault_id=example_key_vault.id,
            key_type="RSA",
            key_size=2048,
            key_opts=[
                "unwrapKey",
                "wrapKey",
            ])
        current_client_policy = azure.keyvault.AccessPolicy("current_client_policy",
            key_vault_id=example_key_vault.id,
            tenant_id=current.tenant_id,
            object_id=current.object_id,
            key_permissions=[
                "Create",
                "Delete",
                "Get",
                "Purge",
                "Recover",
                "Update",
                "GetRotationPolicy",
            ],
            secret_permissions=[
                "Delete",
                "Get",
                "Set",
            ])
        example_factory = azure.datafactory.Factory("example",
            name="example_data_factory",
            location=example.location,
            resource_group_name=example.name,
            identity={
                "type": "SystemAssigned",
                "identity_ids": [example_azurerm_user_assigned_identity["id"]],
            })
        datafactory = azure.keyvault.AccessPolicy("datafactory",
            key_vault_id=example_key_vault.id,
            tenant_id=example_factory.identity.tenant_id,
            object_id=example_factory.identity.principal_id,
            key_permissions=[
                "Create",
                "Delete",
                "Get",
                "Purge",
                "Recover",
                "Update",
                "GetRotationPolicy",
                "WrapKey",
                "UnwrapKey",
            ],
            secret_permissions=[
                "Delete",
                "Get",
                "Set",
            ])
        example_customer_managed_key = azure.datafactory.CustomerManagedKey("example",
            data_factory_id=example_factory.id,
            customer_managed_key_id=example_key.id)
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.DataFactory` - 2018-06-01

        ## Import

        Data Factory Customer Managed Keys can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:datafactory/customerManagedKey:CustomerManagedKey example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/example/providers/Microsoft.DataFactory/factories/example
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] customer_managed_key_id: The ID the of the Customer Managed Key to associate with the Data Factory.
        :param pulumi.Input[_builtins.str] data_factory_id: The ID of the Data Factory Resource the Customer Managed Key will be associated with. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] user_assigned_identity_id: The User Assigned Identity ID that will be used to access Key Vaults that contain the encryption keys.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CustomerManagedKeyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Customer Managed Key for a Data Factory.

        > **Note:** The Customer Managed Key cannot be removed from the Data Factory once added. To remove the Customer Managed Key delete and recreate the parent Data Factory.

        ## Example Usage

        ### With System Assigned Identity

        ```python
        import pulumi
        import pulumi_azure as azure

        current = azure.core.get_client_config()
        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_key_vault = azure.keyvault.KeyVault("example",
            name="example-key-vault",
            location=example.location,
            resource_group_name=example.name,
            tenant_id=current.tenant_id,
            sku_name="standard",
            purge_protection_enabled=True)
        example_key = azure.keyvault.Key("example",
            name="examplekey",
            key_vault_id=example_key_vault.id,
            key_type="RSA",
            key_size=2048,
            key_opts=[
                "unwrapKey",
                "wrapKey",
            ])
        current_client_policy = azure.keyvault.AccessPolicy("current_client_policy",
            key_vault_id=example_key_vault.id,
            tenant_id=current.tenant_id,
            object_id=current.object_id,
            key_permissions=[
                "Create",
                "Delete",
                "Get",
                "Purge",
                "Recover",
                "Update",
                "GetRotationPolicy",
            ],
            secret_permissions=[
                "Delete",
                "Get",
                "Set",
            ])
        example_factory = azure.datafactory.Factory("example",
            name="example_data_factory",
            location=example.location,
            resource_group_name=example.name,
            identity={
                "type": "SystemAssigned",
                "identity_ids": [example_azurerm_user_assigned_identity["id"]],
            })
        datafactory = azure.keyvault.AccessPolicy("datafactory",
            key_vault_id=example_key_vault.id,
            tenant_id=example_factory.identity.tenant_id,
            object_id=example_factory.identity.principal_id,
            key_permissions=[
                "Create",
                "Delete",
                "Get",
                "Purge",
                "Recover",
                "Update",
                "GetRotationPolicy",
                "WrapKey",
                "UnwrapKey",
            ],
            secret_permissions=[
                "Delete",
                "Get",
                "Set",
            ])
        example_customer_managed_key = azure.datafactory.CustomerManagedKey("example",
            data_factory_id=example_factory.id,
            customer_managed_key_id=example_key.id)
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.DataFactory` - 2018-06-01

        ## Import

        Data Factory Customer Managed Keys can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:datafactory/customerManagedKey:CustomerManagedKey example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/example/providers/Microsoft.DataFactory/factories/example
        ```


        :param str resource_name: The name of the resource.
        :param CustomerManagedKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CustomerManagedKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 customer_managed_key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 data_factory_id: Optional[pulumi.Input[_builtins.str]] = None,
                 user_assigned_identity_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CustomerManagedKeyArgs.__new__(CustomerManagedKeyArgs)

            if customer_managed_key_id is None and not opts.urn:
                raise TypeError("Missing required property 'customer_managed_key_id'")
            __props__.__dict__["customer_managed_key_id"] = customer_managed_key_id
            if data_factory_id is None and not opts.urn:
                raise TypeError("Missing required property 'data_factory_id'")
            __props__.__dict__["data_factory_id"] = data_factory_id
            __props__.__dict__["user_assigned_identity_id"] = user_assigned_identity_id
        super(CustomerManagedKey, __self__).__init__(
            'azure:datafactory/customerManagedKey:CustomerManagedKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            customer_managed_key_id: Optional[pulumi.Input[_builtins.str]] = None,
            data_factory_id: Optional[pulumi.Input[_builtins.str]] = None,
            user_assigned_identity_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'CustomerManagedKey':
        """
        Get an existing CustomerManagedKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] customer_managed_key_id: The ID the of the Customer Managed Key to associate with the Data Factory.
        :param pulumi.Input[_builtins.str] data_factory_id: The ID of the Data Factory Resource the Customer Managed Key will be associated with. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] user_assigned_identity_id: The User Assigned Identity ID that will be used to access Key Vaults that contain the encryption keys.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CustomerManagedKeyState.__new__(_CustomerManagedKeyState)

        __props__.__dict__["customer_managed_key_id"] = customer_managed_key_id
        __props__.__dict__["data_factory_id"] = data_factory_id
        __props__.__dict__["user_assigned_identity_id"] = user_assigned_identity_id
        return CustomerManagedKey(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="customerManagedKeyId")
    def customer_managed_key_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID the of the Customer Managed Key to associate with the Data Factory.
        """
        return pulumi.get(self, "customer_managed_key_id")

    @_builtins.property
    @pulumi.getter(name="dataFactoryId")
    def data_factory_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Data Factory Resource the Customer Managed Key will be associated with. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "data_factory_id")

    @_builtins.property
    @pulumi.getter(name="userAssignedIdentityId")
    def user_assigned_identity_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The User Assigned Identity ID that will be used to access Key Vaults that contain the encryption keys.
        """
        return pulumi.get(self, "user_assigned_identity_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetPartnerNamespaceResult',
    'AwaitableGetPartnerNamespaceResult',
    'get_partner_namespace',
    'get_partner_namespace_output',
]

@pulumi.output_type
class GetPartnerNamespaceResult:
    """
    A collection of values returned by getPartnerNamespace.
    """
    def __init__(__self__, endpoint=None, id=None, inbound_ip_rules=None, local_authentication_enabled=None, location=None, name=None, partner_registration_id=None, partner_topic_routing_mode=None, public_network_access=None, resource_group_name=None, tags=None):
        if endpoint and not isinstance(endpoint, str):
            raise TypeError("Expected argument 'endpoint' to be a str")
        pulumi.set(__self__, "endpoint", endpoint)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if inbound_ip_rules and not isinstance(inbound_ip_rules, list):
            raise TypeError("Expected argument 'inbound_ip_rules' to be a list")
        pulumi.set(__self__, "inbound_ip_rules", inbound_ip_rules)
        if local_authentication_enabled and not isinstance(local_authentication_enabled, bool):
            raise TypeError("Expected argument 'local_authentication_enabled' to be a bool")
        pulumi.set(__self__, "local_authentication_enabled", local_authentication_enabled)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if partner_registration_id and not isinstance(partner_registration_id, str):
            raise TypeError("Expected argument 'partner_registration_id' to be a str")
        pulumi.set(__self__, "partner_registration_id", partner_registration_id)
        if partner_topic_routing_mode and not isinstance(partner_topic_routing_mode, str):
            raise TypeError("Expected argument 'partner_topic_routing_mode' to be a str")
        pulumi.set(__self__, "partner_topic_routing_mode", partner_topic_routing_mode)
        if public_network_access and not isinstance(public_network_access, str):
            raise TypeError("Expected argument 'public_network_access' to be a str")
        pulumi.set(__self__, "public_network_access", public_network_access)
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> _builtins.str:
        """
        The endpoint for the Event Grid Partner Namespace.
        """
        return pulumi.get(self, "endpoint")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="inboundIpRules")
    def inbound_ip_rules(self) -> Sequence['outputs.GetPartnerNamespaceInboundIpRuleResult']:
        """
        One or more `inbound_ip_rule` blocks as defined below.
        """
        return pulumi.get(self, "inbound_ip_rules")

    @_builtins.property
    @pulumi.getter(name="localAuthenticationEnabled")
    def local_authentication_enabled(self) -> _builtins.bool:
        """
        Whether local authentication methods are enabled for the Event Grid Partner Namespace.
        """
        return pulumi.get(self, "local_authentication_enabled")

    @_builtins.property
    @pulumi.getter
    def location(self) -> _builtins.str:
        """
        The Azure Region where the Event Grid Partner Namespace exists.
        """
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="partnerRegistrationId")
    def partner_registration_id(self) -> _builtins.str:
        """
        The resource Id of the partner registration associated with this Event Grid Partner Namespace.
        """
        return pulumi.get(self, "partner_registration_id")

    @_builtins.property
    @pulumi.getter(name="partnerTopicRoutingMode")
    def partner_topic_routing_mode(self) -> _builtins.str:
        """
        The partner topic routing mode.
        """
        return pulumi.get(self, "partner_topic_routing_mode")

    @_builtins.property
    @pulumi.getter(name="publicNetworkAccess")
    def public_network_access(self) -> _builtins.str:
        """
        Whether or not public network access is allowed for this server.
        """
        return pulumi.get(self, "public_network_access")

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> _builtins.str:
        return pulumi.get(self, "resource_group_name")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Mapping[str, _builtins.str]:
        """
        A mapping of tags which are assigned to the Event Grid Partner Namespace.
        """
        return pulumi.get(self, "tags")


class AwaitableGetPartnerNamespaceResult(GetPartnerNamespaceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPartnerNamespaceResult(
            endpoint=self.endpoint,
            id=self.id,
            inbound_ip_rules=self.inbound_ip_rules,
            local_authentication_enabled=self.local_authentication_enabled,
            location=self.location,
            name=self.name,
            partner_registration_id=self.partner_registration_id,
            partner_topic_routing_mode=self.partner_topic_routing_mode,
            public_network_access=self.public_network_access,
            resource_group_name=self.resource_group_name,
            tags=self.tags)


def get_partner_namespace(name: Optional[_builtins.str] = None,
                          resource_group_name: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPartnerNamespaceResult:
    """
    Use this data source to access information about an existing Event Grid Partner Namespace

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.eventgrid.get_partner_namespace(name="my-eventgrid-partner-namespace",
        resource_group_name="example-resources")
    pulumi.export("eventgridPartnerNamespaceEndpoint", example.endpoint)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.EventGrid` - 2025-02-15


    :param _builtins.str name: The name of the Event Grid Partner Namespace resource.
    :param _builtins.str resource_group_name: The name of the resource group in which the Event Grid Partner Namespace exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:eventgrid/getPartnerNamespace:getPartnerNamespace', __args__, opts=opts, typ=GetPartnerNamespaceResult).value

    return AwaitableGetPartnerNamespaceResult(
        endpoint=pulumi.get(__ret__, 'endpoint'),
        id=pulumi.get(__ret__, 'id'),
        inbound_ip_rules=pulumi.get(__ret__, 'inbound_ip_rules'),
        local_authentication_enabled=pulumi.get(__ret__, 'local_authentication_enabled'),
        location=pulumi.get(__ret__, 'location'),
        name=pulumi.get(__ret__, 'name'),
        partner_registration_id=pulumi.get(__ret__, 'partner_registration_id'),
        partner_topic_routing_mode=pulumi.get(__ret__, 'partner_topic_routing_mode'),
        public_network_access=pulumi.get(__ret__, 'public_network_access'),
        resource_group_name=pulumi.get(__ret__, 'resource_group_name'),
        tags=pulumi.get(__ret__, 'tags'))
def get_partner_namespace_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPartnerNamespaceResult]:
    """
    Use this data source to access information about an existing Event Grid Partner Namespace

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.eventgrid.get_partner_namespace(name="my-eventgrid-partner-namespace",
        resource_group_name="example-resources")
    pulumi.export("eventgridPartnerNamespaceEndpoint", example.endpoint)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.EventGrid` - 2025-02-15


    :param _builtins.str name: The name of the Event Grid Partner Namespace resource.
    :param _builtins.str resource_group_name: The name of the resource group in which the Event Grid Partner Namespace exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:eventgrid/getPartnerNamespace:getPartnerNamespace', __args__, opts=opts, typ=GetPartnerNamespaceResult)
    return __ret__.apply(lambda __response__: GetPartnerNamespaceResult(
        endpoint=pulumi.get(__response__, 'endpoint'),
        id=pulumi.get(__response__, 'id'),
        inbound_ip_rules=pulumi.get(__response__, 'inbound_ip_rules'),
        local_authentication_enabled=pulumi.get(__response__, 'local_authentication_enabled'),
        location=pulumi.get(__response__, 'location'),
        name=pulumi.get(__response__, 'name'),
        partner_registration_id=pulumi.get(__response__, 'partner_registration_id'),
        partner_topic_routing_mode=pulumi.get(__response__, 'partner_topic_routing_mode'),
        public_network_access=pulumi.get(__response__, 'public_network_access'),
        resource_group_name=pulumi.get(__response__, 'resource_group_name'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['GroupTemplateDeploymentArgs', 'GroupTemplateDeployment']

@pulumi.input_type
class GroupTemplateDeploymentArgs:
    def __init__(__self__, *,
                 management_group_id: pulumi.Input[_builtins.str],
                 debug_level: Optional[pulumi.Input[_builtins.str]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameters_content: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 template_content: Optional[pulumi.Input[_builtins.str]] = None,
                 template_spec_version_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a GroupTemplateDeployment resource.

        :param pulumi.Input[_builtins.str] management_group_id: The ID of the Management Group to apply the Deployment Template to. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] debug_level: The Debug Level which should be used for this Resource Group Template Deployment. Possible values are `none`, `requestContent`, `responseContent` and `requestContent, responseContent`.
        :param pulumi.Input[_builtins.str] location: The Azure Region where the Template should exist. Changing this forces a new Template to be created.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Template Deployment. Changing this forces a new Template Deployment to be created.
        :param pulumi.Input[_builtins.str] parameters_content: The contents of the ARM Template parameters file - containing a JSON list of parameters.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags which should be assigned to the Template.
        :param pulumi.Input[_builtins.str] template_content: The contents of the ARM Template which should be deployed into this Resource Group. Cannot be specified with `template_spec_version_id`.
        :param pulumi.Input[_builtins.str] template_spec_version_id: The ID of the Template Spec Version to deploy. Cannot be specified with `template_content`.
        """
        pulumi.set(__self__, "management_group_id", management_group_id)
        if debug_level is not None:
            pulumi.set(__self__, "debug_level", debug_level)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parameters_content is not None:
            pulumi.set(__self__, "parameters_content", parameters_content)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if template_content is not None:
            pulumi.set(__self__, "template_content", template_content)
        if template_spec_version_id is not None:
            pulumi.set(__self__, "template_spec_version_id", template_spec_version_id)

    @_builtins.property
    @pulumi.getter(name="managementGroupId")
    def management_group_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Management Group to apply the Deployment Template to. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "management_group_id")

    @management_group_id.setter
    def management_group_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "management_group_id", value)

    @_builtins.property
    @pulumi.getter(name="debugLevel")
    def debug_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Debug Level which should be used for this Resource Group Template Deployment. Possible values are `none`, `requestContent`, `responseContent` and `requestContent, responseContent`.
        """
        return pulumi.get(self, "debug_level")

    @debug_level.setter
    def debug_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "debug_level", value)

    @_builtins.property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Azure Region where the Template should exist. Changing this forces a new Template to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "location", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name which should be used for this Template Deployment. Changing this forces a new Template Deployment to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="parametersContent")
    def parameters_content(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The contents of the ARM Template parameters file - containing a JSON list of parameters.
        """
        return pulumi.get(self, "parameters_content")

    @parameters_content.setter
    def parameters_content(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parameters_content", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A mapping of tags which should be assigned to the Template.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="templateContent")
    def template_content(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The contents of the ARM Template which should be deployed into this Resource Group. Cannot be specified with `template_spec_version_id`.
        """
        return pulumi.get(self, "template_content")

    @template_content.setter
    def template_content(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "template_content", value)

    @_builtins.property
    @pulumi.getter(name="templateSpecVersionId")
    def template_spec_version_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Template Spec Version to deploy. Cannot be specified with `template_content`.
        """
        return pulumi.get(self, "template_spec_version_id")

    @template_spec_version_id.setter
    def template_spec_version_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "template_spec_version_id", value)


@pulumi.input_type
class _GroupTemplateDeploymentState:
    def __init__(__self__, *,
                 debug_level: Optional[pulumi.Input[_builtins.str]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 management_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 output_content: Optional[pulumi.Input[_builtins.str]] = None,
                 parameters_content: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 template_content: Optional[pulumi.Input[_builtins.str]] = None,
                 template_spec_version_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering GroupTemplateDeployment resources.

        :param pulumi.Input[_builtins.str] debug_level: The Debug Level which should be used for this Resource Group Template Deployment. Possible values are `none`, `requestContent`, `responseContent` and `requestContent, responseContent`.
        :param pulumi.Input[_builtins.str] location: The Azure Region where the Template should exist. Changing this forces a new Template to be created.
        :param pulumi.Input[_builtins.str] management_group_id: The ID of the Management Group to apply the Deployment Template to. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Template Deployment. Changing this forces a new Template Deployment to be created.
        :param pulumi.Input[_builtins.str] output_content: The JSON Content of the Outputs of the ARM Template Deployment.
        :param pulumi.Input[_builtins.str] parameters_content: The contents of the ARM Template parameters file - containing a JSON list of parameters.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags which should be assigned to the Template.
        :param pulumi.Input[_builtins.str] template_content: The contents of the ARM Template which should be deployed into this Resource Group. Cannot be specified with `template_spec_version_id`.
        :param pulumi.Input[_builtins.str] template_spec_version_id: The ID of the Template Spec Version to deploy. Cannot be specified with `template_content`.
        """
        if debug_level is not None:
            pulumi.set(__self__, "debug_level", debug_level)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if management_group_id is not None:
            pulumi.set(__self__, "management_group_id", management_group_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if output_content is not None:
            pulumi.set(__self__, "output_content", output_content)
        if parameters_content is not None:
            pulumi.set(__self__, "parameters_content", parameters_content)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if template_content is not None:
            pulumi.set(__self__, "template_content", template_content)
        if template_spec_version_id is not None:
            pulumi.set(__self__, "template_spec_version_id", template_spec_version_id)

    @_builtins.property
    @pulumi.getter(name="debugLevel")
    def debug_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Debug Level which should be used for this Resource Group Template Deployment. Possible values are `none`, `requestContent`, `responseContent` and `requestContent, responseContent`.
        """
        return pulumi.get(self, "debug_level")

    @debug_level.setter
    def debug_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "debug_level", value)

    @_builtins.property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Azure Region where the Template should exist. Changing this forces a new Template to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "location", value)

    @_builtins.property
    @pulumi.getter(name="managementGroupId")
    def management_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Management Group to apply the Deployment Template to. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "management_group_id")

    @management_group_id.setter
    def management_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "management_group_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name which should be used for this Template Deployment. Changing this forces a new Template Deployment to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="outputContent")
    def output_content(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The JSON Content of the Outputs of the ARM Template Deployment.
        """
        return pulumi.get(self, "output_content")

    @output_content.setter
    def output_content(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "output_content", value)

    @_builtins.property
    @pulumi.getter(name="parametersContent")
    def parameters_content(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The contents of the ARM Template parameters file - containing a JSON list of parameters.
        """
        return pulumi.get(self, "parameters_content")

    @parameters_content.setter
    def parameters_content(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parameters_content", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A mapping of tags which should be assigned to the Template.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="templateContent")
    def template_content(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The contents of the ARM Template which should be deployed into this Resource Group. Cannot be specified with `template_spec_version_id`.
        """
        return pulumi.get(self, "template_content")

    @template_content.setter
    def template_content(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "template_content", value)

    @_builtins.property
    @pulumi.getter(name="templateSpecVersionId")
    def template_spec_version_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Template Spec Version to deploy. Cannot be specified with `template_content`.
        """
        return pulumi.get(self, "template_spec_version_id")

    @template_spec_version_id.setter
    def template_spec_version_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "template_spec_version_id", value)


@pulumi.type_token("azure:management/groupTemplateDeployment:GroupTemplateDeployment")
class GroupTemplateDeployment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 debug_level: Optional[pulumi.Input[_builtins.str]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 management_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameters_content: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 template_content: Optional[pulumi.Input[_builtins.str]] = None,
                 template_spec_version_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a Template Deployment at a Management Group Scope.

        > **Note:** Deleting a Deployment at the Management Group Scope will not delete any resources created by the deployment.

        > **Note:** Deployments to a Management Group are always Incrementally applied. Existing resources that are not part of the template will not be removed.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.management.get_group(name="00000000-0000-0000-0000-000000000000")
        example_group_template_deployment = azure.management.GroupTemplateDeployment("example",
            name="example",
            location="West Europe",
            management_group_id=example.id,
            template_content=\"\"\"{
          \\"$schema\\": \\"https://schema.management.azure.com/schemas/2019-04-01/deploymentTemplate.json#\\",
          \\"contentVersion\\": \\"1.0.0.0\\",
          \\"parameters\\": {
            \\"policyAssignmentName\\": {
              \\"type\\": \\"string\\",
              \\"defaultValue\\": \\"[guid(parameters('policyDefinitionID'), resourceGroup().name)]\\",
              \\"metadata\\": {
                \\"description\\": \\"Specifies the name of the policy assignment, can be used defined or an idempotent name as the defaultValue provides.\\"
              }
            },
            \\"policyDefinitionID\\": {
              \\"type\\": \\"string\\",
              \\"metadata\\": {
                \\"description\\": \\"Specifies the ID of the policy definition or policy set definition being assigned.\\"
              }
            }
          },
          \\"resources\\": [
            {
              \\"type\\": \\"Microsoft.Authorization/policyAssignments\\",
              \\"name\\": \\"[parameters('policyAssignmentName')]\\",
              \\"apiVersion\\": \\"2019-09-01\\",
              \\"properties\\": {
                \\"scope\\": \\"[subscriptionResourceId('Microsoft.Resources/resourceGroups', resourceGroup().name)]\\",
                \\"policyDefinitionId\\": \\"[parameters('policyDefinitionID')]\\"
              }
            }
          ]
        }
        \"\"\",
            parameters_content=\"\"\"{
          \\"$schema\\": \\"https://schema.management.azure.com/schemas/2019-04-01/deploymentParameters.json#\\",
          \\"contentVersion\\": \\"1.0.0.0\\",
          \\"parameters\\": {
            \\"policyDefinitionID\\": {
              \\"value\\": \\"/providers/Microsoft.Authorization/policyDefinitions/0a914e76-4921-4c19-b460-a2d36003525a\\"
            }
          }
        }
        \"\"\")
        ```

        ```python
        import pulumi
        import pulumi_azure as azure
        import pulumi_std as std

        example = azure.management.get_group(name="00000000-0000-0000-0000-000000000000")
        example_group_template_deployment = azure.management.GroupTemplateDeployment("example",
            name="example",
            location="West Europe",
            management_group_id=example.id,
            template_content=std.file(input="templates/example-deploy-template.json").result,
            parameters_content=std.file(input="templates/example-deploy-params.json").result)
        ```

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.management.get_group(name="00000000-0000-0000-0000-000000000000")
        example_get_template_spec_version = azure.core.get_template_spec_version(name="exampleTemplateForManagementGroup",
            resource_group_name="exampleResourceGroup",
            version="v1.0.9")
        example_group_template_deployment = azure.management.GroupTemplateDeployment("example",
            name="example",
            location="West Europe",
            management_group_id=example.id,
            template_spec_version_id=example_get_template_spec_version.id)
        ```

        ## Import

        Management Group Template Deployments can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:management/groupTemplateDeployment:GroupTemplateDeployment example /providers/Microsoft.Management/managementGroups/my-management-group-id/providers/Microsoft.Resources/deployments/deploy1
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] debug_level: The Debug Level which should be used for this Resource Group Template Deployment. Possible values are `none`, `requestContent`, `responseContent` and `requestContent, responseContent`.
        :param pulumi.Input[_builtins.str] location: The Azure Region where the Template should exist. Changing this forces a new Template to be created.
        :param pulumi.Input[_builtins.str] management_group_id: The ID of the Management Group to apply the Deployment Template to. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Template Deployment. Changing this forces a new Template Deployment to be created.
        :param pulumi.Input[_builtins.str] parameters_content: The contents of the ARM Template parameters file - containing a JSON list of parameters.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags which should be assigned to the Template.
        :param pulumi.Input[_builtins.str] template_content: The contents of the ARM Template which should be deployed into this Resource Group. Cannot be specified with `template_spec_version_id`.
        :param pulumi.Input[_builtins.str] template_spec_version_id: The ID of the Template Spec Version to deploy. Cannot be specified with `template_content`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupTemplateDeploymentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Template Deployment at a Management Group Scope.

        > **Note:** Deleting a Deployment at the Management Group Scope will not delete any resources created by the deployment.

        > **Note:** Deployments to a Management Group are always Incrementally applied. Existing resources that are not part of the template will not be removed.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.management.get_group(name="00000000-0000-0000-0000-000000000000")
        example_group_template_deployment = azure.management.GroupTemplateDeployment("example",
            name="example",
            location="West Europe",
            management_group_id=example.id,
            template_content=\"\"\"{
          \\"$schema\\": \\"https://schema.management.azure.com/schemas/2019-04-01/deploymentTemplate.json#\\",
          \\"contentVersion\\": \\"1.0.0.0\\",
          \\"parameters\\": {
            \\"policyAssignmentName\\": {
              \\"type\\": \\"string\\",
              \\"defaultValue\\": \\"[guid(parameters('policyDefinitionID'), resourceGroup().name)]\\",
              \\"metadata\\": {
                \\"description\\": \\"Specifies the name of the policy assignment, can be used defined or an idempotent name as the defaultValue provides.\\"
              }
            },
            \\"policyDefinitionID\\": {
              \\"type\\": \\"string\\",
              \\"metadata\\": {
                \\"description\\": \\"Specifies the ID of the policy definition or policy set definition being assigned.\\"
              }
            }
          },
          \\"resources\\": [
            {
              \\"type\\": \\"Microsoft.Authorization/policyAssignments\\",
              \\"name\\": \\"[parameters('policyAssignmentName')]\\",
              \\"apiVersion\\": \\"2019-09-01\\",
              \\"properties\\": {
                \\"scope\\": \\"[subscriptionResourceId('Microsoft.Resources/resourceGroups', resourceGroup().name)]\\",
                \\"policyDefinitionId\\": \\"[parameters('policyDefinitionID')]\\"
              }
            }
          ]
        }
        \"\"\",
            parameters_content=\"\"\"{
          \\"$schema\\": \\"https://schema.management.azure.com/schemas/2019-04-01/deploymentParameters.json#\\",
          \\"contentVersion\\": \\"1.0.0.0\\",
          \\"parameters\\": {
            \\"policyDefinitionID\\": {
              \\"value\\": \\"/providers/Microsoft.Authorization/policyDefinitions/0a914e76-4921-4c19-b460-a2d36003525a\\"
            }
          }
        }
        \"\"\")
        ```

        ```python
        import pulumi
        import pulumi_azure as azure
        import pulumi_std as std

        example = azure.management.get_group(name="00000000-0000-0000-0000-000000000000")
        example_group_template_deployment = azure.management.GroupTemplateDeployment("example",
            name="example",
            location="West Europe",
            management_group_id=example.id,
            template_content=std.file(input="templates/example-deploy-template.json").result,
            parameters_content=std.file(input="templates/example-deploy-params.json").result)
        ```

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.management.get_group(name="00000000-0000-0000-0000-000000000000")
        example_get_template_spec_version = azure.core.get_template_spec_version(name="exampleTemplateForManagementGroup",
            resource_group_name="exampleResourceGroup",
            version="v1.0.9")
        example_group_template_deployment = azure.management.GroupTemplateDeployment("example",
            name="example",
            location="West Europe",
            management_group_id=example.id,
            template_spec_version_id=example_get_template_spec_version.id)
        ```

        ## Import

        Management Group Template Deployments can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:management/groupTemplateDeployment:GroupTemplateDeployment example /providers/Microsoft.Management/managementGroups/my-management-group-id/providers/Microsoft.Resources/deployments/deploy1
        ```


        :param str resource_name: The name of the resource.
        :param GroupTemplateDeploymentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupTemplateDeploymentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 debug_level: Optional[pulumi.Input[_builtins.str]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 management_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameters_content: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 template_content: Optional[pulumi.Input[_builtins.str]] = None,
                 template_spec_version_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupTemplateDeploymentArgs.__new__(GroupTemplateDeploymentArgs)

            __props__.__dict__["debug_level"] = debug_level
            __props__.__dict__["location"] = location
            if management_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'management_group_id'")
            __props__.__dict__["management_group_id"] = management_group_id
            __props__.__dict__["name"] = name
            __props__.__dict__["parameters_content"] = parameters_content
            __props__.__dict__["tags"] = tags
            __props__.__dict__["template_content"] = template_content
            __props__.__dict__["template_spec_version_id"] = template_spec_version_id
            __props__.__dict__["output_content"] = None
        super(GroupTemplateDeployment, __self__).__init__(
            'azure:management/groupTemplateDeployment:GroupTemplateDeployment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            debug_level: Optional[pulumi.Input[_builtins.str]] = None,
            location: Optional[pulumi.Input[_builtins.str]] = None,
            management_group_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            output_content: Optional[pulumi.Input[_builtins.str]] = None,
            parameters_content: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            template_content: Optional[pulumi.Input[_builtins.str]] = None,
            template_spec_version_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'GroupTemplateDeployment':
        """
        Get an existing GroupTemplateDeployment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] debug_level: The Debug Level which should be used for this Resource Group Template Deployment. Possible values are `none`, `requestContent`, `responseContent` and `requestContent, responseContent`.
        :param pulumi.Input[_builtins.str] location: The Azure Region where the Template should exist. Changing this forces a new Template to be created.
        :param pulumi.Input[_builtins.str] management_group_id: The ID of the Management Group to apply the Deployment Template to. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Template Deployment. Changing this forces a new Template Deployment to be created.
        :param pulumi.Input[_builtins.str] output_content: The JSON Content of the Outputs of the ARM Template Deployment.
        :param pulumi.Input[_builtins.str] parameters_content: The contents of the ARM Template parameters file - containing a JSON list of parameters.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags which should be assigned to the Template.
        :param pulumi.Input[_builtins.str] template_content: The contents of the ARM Template which should be deployed into this Resource Group. Cannot be specified with `template_spec_version_id`.
        :param pulumi.Input[_builtins.str] template_spec_version_id: The ID of the Template Spec Version to deploy. Cannot be specified with `template_content`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupTemplateDeploymentState.__new__(_GroupTemplateDeploymentState)

        __props__.__dict__["debug_level"] = debug_level
        __props__.__dict__["location"] = location
        __props__.__dict__["management_group_id"] = management_group_id
        __props__.__dict__["name"] = name
        __props__.__dict__["output_content"] = output_content
        __props__.__dict__["parameters_content"] = parameters_content
        __props__.__dict__["tags"] = tags
        __props__.__dict__["template_content"] = template_content
        __props__.__dict__["template_spec_version_id"] = template_spec_version_id
        return GroupTemplateDeployment(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="debugLevel")
    def debug_level(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The Debug Level which should be used for this Resource Group Template Deployment. Possible values are `none`, `requestContent`, `responseContent` and `requestContent, responseContent`.
        """
        return pulumi.get(self, "debug_level")

    @_builtins.property
    @pulumi.getter
    def location(self) -> pulumi.Output[_builtins.str]:
        """
        The Azure Region where the Template should exist. Changing this forces a new Template to be created.
        """
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter(name="managementGroupId")
    def management_group_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Management Group to apply the Deployment Template to. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "management_group_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name which should be used for this Template Deployment. Changing this forces a new Template Deployment to be created.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="outputContent")
    def output_content(self) -> pulumi.Output[_builtins.str]:
        """
        The JSON Content of the Outputs of the ARM Template Deployment.
        """
        return pulumi.get(self, "output_content")

    @_builtins.property
    @pulumi.getter(name="parametersContent")
    def parameters_content(self) -> pulumi.Output[_builtins.str]:
        """
        The contents of the ARM Template parameters file - containing a JSON list of parameters.
        """
        return pulumi.get(self, "parameters_content")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        A mapping of tags which should be assigned to the Template.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="templateContent")
    def template_content(self) -> pulumi.Output[_builtins.str]:
        """
        The contents of the ARM Template which should be deployed into this Resource Group. Cannot be specified with `template_spec_version_id`.
        """
        return pulumi.get(self, "template_content")

    @_builtins.property
    @pulumi.getter(name="templateSpecVersionId")
    def template_spec_version_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The ID of the Template Spec Version to deploy. Cannot be specified with `template_content`.
        """
        return pulumi.get(self, "template_spec_version_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 identity_provider_type: pulumi.Input[_builtins.str],
                 mongo_cluster_id: pulumi.Input[_builtins.str],
                 object_id: pulumi.Input[_builtins.str],
                 principal_type: pulumi.Input[_builtins.str],
                 roles: pulumi.Input[Sequence[pulumi.Input['UserRoleArgs']]]):
        """
        The set of arguments for constructing a User resource.

        :param pulumi.Input[_builtins.str] identity_provider_type: The identity provider type for the Mongo Cluster User. The only possible value is `MicrosoftEntraID`. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] mongo_cluster_id: The ID of the Mongo Cluster where the User should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] object_id: The Object ID of the Entra ID User or Service Principal. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] principal_type: The principal type for the Mongo Cluster User. Possible values are `user` and `servicePrincipal`. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input['UserRoleArgs']]] roles: One or more `role` blocks as defined below. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "identity_provider_type", identity_provider_type)
        pulumi.set(__self__, "mongo_cluster_id", mongo_cluster_id)
        pulumi.set(__self__, "object_id", object_id)
        pulumi.set(__self__, "principal_type", principal_type)
        pulumi.set(__self__, "roles", roles)

    @_builtins.property
    @pulumi.getter(name="identityProviderType")
    def identity_provider_type(self) -> pulumi.Input[_builtins.str]:
        """
        The identity provider type for the Mongo Cluster User. The only possible value is `MicrosoftEntraID`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "identity_provider_type")

    @identity_provider_type.setter
    def identity_provider_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identity_provider_type", value)

    @_builtins.property
    @pulumi.getter(name="mongoClusterId")
    def mongo_cluster_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Mongo Cluster where the User should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "mongo_cluster_id")

    @mongo_cluster_id.setter
    def mongo_cluster_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "mongo_cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="objectId")
    def object_id(self) -> pulumi.Input[_builtins.str]:
        """
        The Object ID of the Entra ID User or Service Principal. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "object_id")

    @object_id.setter
    def object_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "object_id", value)

    @_builtins.property
    @pulumi.getter(name="principalType")
    def principal_type(self) -> pulumi.Input[_builtins.str]:
        """
        The principal type for the Mongo Cluster User. Possible values are `user` and `servicePrincipal`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "principal_type")

    @principal_type.setter
    def principal_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "principal_type", value)

    @_builtins.property
    @pulumi.getter
    def roles(self) -> pulumi.Input[Sequence[pulumi.Input['UserRoleArgs']]]:
        """
        One or more `role` blocks as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: pulumi.Input[Sequence[pulumi.Input['UserRoleArgs']]]):
        pulumi.set(self, "roles", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 identity_provider_type: Optional[pulumi.Input[_builtins.str]] = None,
                 mongo_cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 object_id: Optional[pulumi.Input[_builtins.str]] = None,
                 principal_type: Optional[pulumi.Input[_builtins.str]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input['UserRoleArgs']]]] = None):
        """
        Input properties used for looking up and filtering User resources.

        :param pulumi.Input[_builtins.str] identity_provider_type: The identity provider type for the Mongo Cluster User. The only possible value is `MicrosoftEntraID`. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] mongo_cluster_id: The ID of the Mongo Cluster where the User should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] object_id: The Object ID of the Entra ID User or Service Principal. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] principal_type: The principal type for the Mongo Cluster User. Possible values are `user` and `servicePrincipal`. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input['UserRoleArgs']]] roles: One or more `role` blocks as defined below. Changing this forces a new resource to be created.
        """
        if identity_provider_type is not None:
            pulumi.set(__self__, "identity_provider_type", identity_provider_type)
        if mongo_cluster_id is not None:
            pulumi.set(__self__, "mongo_cluster_id", mongo_cluster_id)
        if object_id is not None:
            pulumi.set(__self__, "object_id", object_id)
        if principal_type is not None:
            pulumi.set(__self__, "principal_type", principal_type)
        if roles is not None:
            pulumi.set(__self__, "roles", roles)

    @_builtins.property
    @pulumi.getter(name="identityProviderType")
    def identity_provider_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The identity provider type for the Mongo Cluster User. The only possible value is `MicrosoftEntraID`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "identity_provider_type")

    @identity_provider_type.setter
    def identity_provider_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identity_provider_type", value)

    @_builtins.property
    @pulumi.getter(name="mongoClusterId")
    def mongo_cluster_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Mongo Cluster where the User should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "mongo_cluster_id")

    @mongo_cluster_id.setter
    def mongo_cluster_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mongo_cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="objectId")
    def object_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Object ID of the Entra ID User or Service Principal. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "object_id")

    @object_id.setter
    def object_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "object_id", value)

    @_builtins.property
    @pulumi.getter(name="principalType")
    def principal_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The principal type for the Mongo Cluster User. Possible values are `user` and `servicePrincipal`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "principal_type")

    @principal_type.setter
    def principal_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "principal_type", value)

    @_builtins.property
    @pulumi.getter
    def roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['UserRoleArgs']]]]:
        """
        One or more `role` blocks as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['UserRoleArgs']]]]):
        pulumi.set(self, "roles", value)


@pulumi.type_token("azure:mongocluster/user:User")
class User(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 identity_provider_type: Optional[pulumi.Input[_builtins.str]] = None,
                 mongo_cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 object_id: Optional[pulumi.Input[_builtins.str]] = None,
                 principal_type: Optional[pulumi.Input[_builtins.str]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UserRoleArgs', 'UserRoleArgsDict']]]]] = None,
                 __props__=None):
        """
        Manages a Mongo Cluster User.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        current = azure.core.get_client_config()
        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_mongo_cluster = azure.mongocluster.MongoCluster("example",
            name="example-mc",
            resource_group_name=example.name,
            location=example.location,
            administrator_username="adminTerraform",
            administrator_password="QAZwsx123",
            shard_count=1,
            compute_tier="M30",
            high_availability_mode="Disabled",
            storage_size_in_gb=32,
            version="8.0",
            authentication_methods=[
                "NativeAuth",
                "MicrosoftEntraID",
            ])
        example_user = azure.mongocluster.User("example",
            object_id=current.object_id,
            mongo_cluster_id=example_mongo_cluster.id,
            identity_provider_type="MicrosoftEntraID",
            principal_type="servicePrincipal",
            roles=[{
                "database": "admin",
                "name": "root",
            }])
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.DocumentDB` - 2025-09-01

        ## Import

        Mongo Cluster Users can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:mongocluster/user:User example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.DocumentDB/mongoClusters/cluster1/users/user1
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] identity_provider_type: The identity provider type for the Mongo Cluster User. The only possible value is `MicrosoftEntraID`. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] mongo_cluster_id: The ID of the Mongo Cluster where the User should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] object_id: The Object ID of the Entra ID User or Service Principal. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] principal_type: The principal type for the Mongo Cluster User. Possible values are `user` and `servicePrincipal`. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['UserRoleArgs', 'UserRoleArgsDict']]]] roles: One or more `role` blocks as defined below. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Mongo Cluster User.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        current = azure.core.get_client_config()
        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_mongo_cluster = azure.mongocluster.MongoCluster("example",
            name="example-mc",
            resource_group_name=example.name,
            location=example.location,
            administrator_username="adminTerraform",
            administrator_password="QAZwsx123",
            shard_count=1,
            compute_tier="M30",
            high_availability_mode="Disabled",
            storage_size_in_gb=32,
            version="8.0",
            authentication_methods=[
                "NativeAuth",
                "MicrosoftEntraID",
            ])
        example_user = azure.mongocluster.User("example",
            object_id=current.object_id,
            mongo_cluster_id=example_mongo_cluster.id,
            identity_provider_type="MicrosoftEntraID",
            principal_type="servicePrincipal",
            roles=[{
                "database": "admin",
                "name": "root",
            }])
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.DocumentDB` - 2025-09-01

        ## Import

        Mongo Cluster Users can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:mongocluster/user:User example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.DocumentDB/mongoClusters/cluster1/users/user1
        ```


        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 identity_provider_type: Optional[pulumi.Input[_builtins.str]] = None,
                 mongo_cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 object_id: Optional[pulumi.Input[_builtins.str]] = None,
                 principal_type: Optional[pulumi.Input[_builtins.str]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UserRoleArgs', 'UserRoleArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            if identity_provider_type is None and not opts.urn:
                raise TypeError("Missing required property 'identity_provider_type'")
            __props__.__dict__["identity_provider_type"] = identity_provider_type
            if mongo_cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'mongo_cluster_id'")
            __props__.__dict__["mongo_cluster_id"] = mongo_cluster_id
            if object_id is None and not opts.urn:
                raise TypeError("Missing required property 'object_id'")
            __props__.__dict__["object_id"] = object_id
            if principal_type is None and not opts.urn:
                raise TypeError("Missing required property 'principal_type'")
            __props__.__dict__["principal_type"] = principal_type
            if roles is None and not opts.urn:
                raise TypeError("Missing required property 'roles'")
            __props__.__dict__["roles"] = roles
        super(User, __self__).__init__(
            'azure:mongocluster/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            identity_provider_type: Optional[pulumi.Input[_builtins.str]] = None,
            mongo_cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
            object_id: Optional[pulumi.Input[_builtins.str]] = None,
            principal_type: Optional[pulumi.Input[_builtins.str]] = None,
            roles: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UserRoleArgs', 'UserRoleArgsDict']]]]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] identity_provider_type: The identity provider type for the Mongo Cluster User. The only possible value is `MicrosoftEntraID`. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] mongo_cluster_id: The ID of the Mongo Cluster where the User should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] object_id: The Object ID of the Entra ID User or Service Principal. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] principal_type: The principal type for the Mongo Cluster User. Possible values are `user` and `servicePrincipal`. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['UserRoleArgs', 'UserRoleArgsDict']]]] roles: One or more `role` blocks as defined below. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["identity_provider_type"] = identity_provider_type
        __props__.__dict__["mongo_cluster_id"] = mongo_cluster_id
        __props__.__dict__["object_id"] = object_id
        __props__.__dict__["principal_type"] = principal_type
        __props__.__dict__["roles"] = roles
        return User(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="identityProviderType")
    def identity_provider_type(self) -> pulumi.Output[_builtins.str]:
        """
        The identity provider type for the Mongo Cluster User. The only possible value is `MicrosoftEntraID`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "identity_provider_type")

    @_builtins.property
    @pulumi.getter(name="mongoClusterId")
    def mongo_cluster_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Mongo Cluster where the User should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "mongo_cluster_id")

    @_builtins.property
    @pulumi.getter(name="objectId")
    def object_id(self) -> pulumi.Output[_builtins.str]:
        """
        The Object ID of the Entra ID User or Service Principal. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "object_id")

    @_builtins.property
    @pulumi.getter(name="principalType")
    def principal_type(self) -> pulumi.Output[_builtins.str]:
        """
        The principal type for the Mongo Cluster User. Possible values are `user` and `servicePrincipal`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "principal_type")

    @_builtins.property
    @pulumi.getter
    def roles(self) -> pulumi.Output[Sequence['outputs.UserRole']]:
        """
        One or more `role` blocks as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "roles")

